﻿using System;
using System.Drawing;

using DevExpress.XtraEditors;
using DevExpress.XtraMap;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            Load += Form_Load;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 폼 로드시 처리하기 - Form_Load(sender, e)

        /// <summary>
        /// 폼 로드시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void Form_Load(object sender, EventArgs e)
        {
            #region 맵 항목 저장소를 설정한다.

            MapItemStorage mapItemStorage = new MapItemStorage();

            mapItemStorage.Items.Add
            (
                new MapBubble()
                {
                    Argument   = "A",
                    Value      = 200,
                    Location   = new GeoPoint(-45, -60),
                    Size       = 20,
                    Group      = 1,
                    MarkerType = MarkerType.Diamond
                }
            );

            mapItemStorage.Items.Add
            (
                new MapBubble()
                {
                    Argument   = "B",
                    Value      = 400,
                    Location   = new GeoPoint(-45, 0),
                    Size       = 40,
                    Group      = 2,
                    MarkerType = MarkerType.Plus
                }
            );

            mapItemStorage.Items.Add
            (
                new MapBubble()
                {
                    Argument   = "C",
                    Value      = 800,
                    Location   = new GeoPoint(-45, 60),
                    Size       = 80,
                    Group      = 1,
                    MarkerType = MarkerType.Cross
                }
            );

            #endregion
            #region 키 색상 색상화기를 설정한다.

            KeyColorColorizer keyColorColorizer = new KeyColorColorizer();

            keyColorColorizer.ItemKeyProvider = new ArgumentItemKeyProvider();

            keyColorColorizer.Colors.Add(Color.Coral    );
            keyColorColorizer.Colors.Add(Color.Orange   );
            keyColorColorizer.Colors.Add(Color.LightBlue);

            keyColorColorizer.Keys.Add(new ColorizerKeyItem() { Key = "A", Name = "Category A" });
            keyColorColorizer.Keys.Add(new ColorizerKeyItem() { Key = "B", Name = "Category B" });
            keyColorColorizer.Keys.Add(new ColorizerKeyItem() { Key = "C", Name = "Category C" });

            #endregion
            #region 벡터 항목 레이어를 설정한다.

            VectorItemsLayer vectorItemsLayer = new VectorItemsLayer();

            vectorItemsLayer.Data      = mapItemStorage;
            vectorItemsLayer.Colorizer = keyColorColorizer;

            this.mapControl.Layers.Add(vectorItemsLayer);

            #endregion
            #region 색상 리스트 레전드를 설정한다.

            ColorListLegend colorListLegend = new ColorListLegend();

            colorListLegend.Layer = vectorItemsLayer;

            this.mapControl.Legends.Add(colorListLegend);

            #endregion
        }

        #endregion
    }
}